@@ -510,7 +510,7 @@ static int encode_APDU(ZOOM_connection c, Z_APDU *a, ODR out)
         yaz_oi_set_string_oid(oi, out, yaz_oid_userinfo_cookie,
                               1, c->cookie_out);
     }
-    if (c->client_IP)
+    if (c->client_IP && a->which == Z_APDU_initRequest)
     {
         Z_OtherInformation **oi;
         yaz_oi_APDU(a, &oi);
@@ -1554,7 +1554,7 @@ zoom_ret ZOOM_connection_Z3950_search(ZOOM_connection c)
     ZOOM_resultset resultset;
     int *start, *count;
 
-    if (!c->tasks)
+    if (!c->tasks || c->tasks->which == ZOOM_TASK_SORT)
         return zoom_complete;
     assert(c->tasks->which == ZOOM_TASK_SEARCH);
     resultset = c->tasks->u.search.resultset;
